@@ -20,7 +20,10 @@ class Source:
     async def __aiter__(self):
         raise NotImplementedError
 
-    async def get_full_data(self, sync: Sync):
+    async def get_full_data(self, sync: Sync, size: int):
+        raise NotImplementedError
+
+    async def get_current_progress(self):
         raise NotImplementedError
 
     async def get_count(self, sync: Sync):
